AshAuthentication.Supervisor (ash_authentication v4.15.0)
View SourceStarts and manages any processes required by AshAuthentication.
Add to your application supervisor:
Example
defmodule MyApp.Application do
use Application
def start(_type, _args) do
children = [
{AshAuthentication.Supervisor, otp_app: :my_app}
]
Supervisor.start_link(children, strategy: :one_for_one, name: MyApp.Supervisor)
end
endThe supervisor also checks configuration which cannot be checked when the
resources compile. It refuses to start when a resource uses the audit log
add-on with ip_privacy_mode :hash and no IP salt is configured. See
AshAuthentication.AddOn.AuditLog.IpPrivacy.
Summary
Functions
Returns a specification to start this module under a supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.